Learn R Programming

ascotraceR (version 0.0.1)

ascotraceR-package: ascotraceR: Simulate the Spread of Ascochyta Blight in Chickpea

Description

A spatiotemporal model that simulates the spread of Ascochyta blight in chickpea fields based on location-specific weather conditions. This model is adapted from a model developed by Diggle et al. (2002) <doi:10.1094/PHYTO.2002.92.10.1110> for simulating the spread of anthracnose in a lupin field.

Arguments

See Also

Useful links: